@@ -82,6 +82,8 @@ hook_plot_tex = function(x, options) {
     }
   }
 
+  # maxwidth does not work with animations
+  if (animate && identical(options$out.width, '\\maxwidth')) options$out.width = NULL
   size = paste(c(sprintf('width=%s', options$out.width),
                  sprintf('height=%s', options$out.height)), collapse = ',')
 
@@ -113,7 +115,7 @@ hook_plot_tex = function(x, options) {
   x = str_c(k1, x, k2)
   ## rm empty kframe and verbatim environments
   x = gsub('\\\\begin\\{(kframe)\\}\\s*\\\\end\\{\\1\\}', '', x)
-  x = gsub('\\\\end\\{(verbatim)\\}\\s*\\\\begin\\{\\1\\}[\n]?', '', x)
+  x = gsub('\\\\end\\{(verbatim)\\}\\s*\\\\begin\\{\\1\\}[\n]?', '\n', x)
   size = if (options$size == 'normalsize') '' else str_c('\\', options$size)
   if (!ai) x = str_c('\\begin{knitrout}', size, '\n', x, '\n\\end{knitrout}')
   if (options$split) {
@@ -178,6 +180,7 @@ render_latex = function() {
   knit_hooks$restore()
   knit_hooks$set(source = function(x, options) {
     if (options$highlight) {
+      if (!has_package('highlight')) return(x)
       ## gsub() makes sure " will not produce an umlaut
       str_c('\\begin{flushleft}\n', gsub('"', '"{}', x, fixed = TRUE),
             '\\end{flushleft}\n')
