@@ -92,7 +92,8 @@ save_plot = function(plot, name, dev, ext, dpi, options) {
                   get(dev, mode = 'function'))
   
   ## re-plot the recorded plot to an off-screen device
-  device(path, width = options$fig.width, height = options$fig.height)
+  do.call(device, c(list(path, width = options$fig.width, height = options$fig.height),
+                    options$dev.args))
   print(plot)
   dev.off()
   
@@ -102,7 +103,7 @@ save_plot = function(plot, name, dev, ext, dpi, options) {
     owd = setwd(dirname(path))
     # add old wd to TEXINPUTS (see #188)
     oti = Sys.getenv('TEXINPUTS'); on.exit(Sys.setenv(TEXINPUTS = oti))
-    Sys.setenv(TEXINPUTS = str_c('.', owd, oti, sep = ':'))
+    Sys.setenv(TEXINPUTS = str_c(owd, oti, sep = ':'))
     system(str_c(switch(getOption("tikzDefaultEngine"),
                         pdftex = getOption('tikzLatex'),
                         xetex = getOption("tikzXelatex"),
